==> flink-runtime_2.11-1.6.2-sources.jar: org/apache/flink/runtime/rest/messages/job/metrics/JobManagerMetricsMessageParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages.job.metrics;

import org.apache.flink.runtime.rest.messages.MessageParameters;
import org.apache.flink.runtime.rest.messages.MessagePathParameter;
import org.apache.flink.runtime.rest.messages.MessageQueryParameter;

import java.util.Collection;
import java.util.Collections;

/**
 * {@link MessageParameters} for
 * {@link org.apache.flink.runtime.rest.handler.job.metrics.JobManagerMetricsHandler}.
 */
public class JobManagerMetricsMessageParameters extends MessageParameters {

	private final MetricsFilterParameter metricsFilterParameter = new MetricsFilterParameter();

	@Override
	public Collection<MessagePathParameter<?>> getPathParameters() {
		return Collections.emptyList();
	}

	@Override
	public Collection<MessageQueryParameter<?>> getQueryParameters() {
		return Collections.singleton(metricsFilterParameter);
	}

}

==> flink-runtime_2.12-1.10.1-sources.jar: org/apache/flink/runtime/rest/messages/job/metrics/JobManagerMetricsMessageParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages.job.metrics;

import org.apache.flink.runtime.rest.messages.MessageParameters;
import org.apache.flink.runtime.rest.messages.MessagePathParameter;
import org.apache.flink.runtime.rest.messages.MessageQueryParameter;

import java.util.Collection;
import java.util.Collections;

/**
 * {@link MessageParameters} for
 * {@link org.apache.flink.runtime.rest.handler.job.metrics.JobManagerMetricsHandler}.
 */
public class JobManagerMetricsMessageParameters extends MessageParameters {

	public final MetricsFilterParameter metricsFilterParameter = new MetricsFilterParameter();

	@Override
	public Collection<MessagePathParameter<?>> getPathParameters() {
		return Collections.emptyList();
	}

	@Override
	public Collection<MessageQueryParameter<?>> getQueryParameters() {
		return Collections.singleton(metricsFilterParameter);
	}

}
